@@ -29,6 +29,7 @@ class AgGrid(JustpyBaseComponent):
         self.options = Dict(self.default_grid_options)
         self.classes = ''
         self.style = 'height: 99vh; width: 99%; margin: 0.25rem; padding: 0.25rem;'
+        self.evaluate = []  # Fields for evaluation
         self.show = True
         self.pages = {}
         self.auto_size = True   # If True, automatically resize columns after load to optimal fit
@@ -95,6 +96,16 @@ class AgGrid(JustpyBaseComponent):
         # Change NaN and similar to None for JSON compatibility
         self.options.rowData = df.replace([np.inf, -np.inf], [sys.float_info.max, -sys.float_info.max]).where(pd.notnull(df), None).to_dict('records')
 
+    async def run_api(self, command, page):
+        await page.run_javascript(f"""cached_grid_def['g' + {self.id}].api.{command}""")
+
+    async def select_all_rows(self, page):
+        await page.run_javascript(f"""cached_grid_def['g' + {self.id}].api.selectAll()""")
+
+    async def deselect_rows(self, page):
+        await page.run_javascript(f"""cached_grid_def['g' + {self.id}].api.deselectAll()""")
+
+
     def convert_object_to_dict(self):
 
         d = {}
@@ -107,4 +118,5 @@ class AgGrid(JustpyBaseComponent):
         d['auto_size'] = self.auto_size
         d['events'] = self.events
         d['html_columns'] = self.html_columns
+        d['evaluate'] = self.evaluate
         return d
