@@ -5,12 +5,16 @@ class Tailwind:
     # TODO: Customization - https://tailwindcss.com/docs/configuration
     pseudo_classes = ['hover', 'focus', 'active', 'group-hover', 'focus-within',
                       'first', 'last', 'odd', 'even', 'disabled', 'visited',
-                      'sm', 'md', 'lg', 'xl']
+                      'sm', 'md', 'lg', 'xl', 'group-focus']
 
     tw_dict = {'container': ['container'],
+               'screen_reader': ['sr-only', 'not-sr-only'],
                'display': ['block', 'inline-block', 'inline', 'flex', 'inline-flex', 'table', 'table-row', 'table-cell',
-                           'hidden', 'grid'],
+                           'table-caption', 'table-column', 'table-column-group', 'table-header-group',
+                           'table-row-group', 'table-footer-group',
+                           'hidden', 'grid', 'inline-grid', 'flow-root'],
                'float': ['float-right', 'float-left', 'float-none', 'clearfix'],
+               'clear': ['clear-right', 'clear-left', 'clear-none', 'clear-both'],
                'object_fit': ['object-contain', 'object-cover', 'object-fill', 'object-none', 'object-scale-down'],
                'object_position': ['object-bottom', 'object-center', 'object-left', 'object-left-bottom',
                                    'object-left-top',
@@ -40,7 +44,8 @@ class Tailwind:
                'list_style_type': ['list-none', 'list-disc', 'list-decimal'],
                'list_style_position': ['list-inside', 'list-outside'],
                'text_align': ['text-left', 'text-center', 'text-right', 'text-justify'],
-               'text_color': ['text-transparent', 'text-black', 'text-white', 'text-gray-100', 'text-gray-200',
+               'text_color': ['text-transparent', 'text-current', 'text-black', 'text-white', 'text-gray-100',
+                              'text-gray-200',
                               'text-gray-300', 'text-gray-400', 'text-gray-500', 'text-gray-600', 'text-gray-700',
                               'text-gray-800', 'text-gray-900', 'text-red-100', 'text-red-200', 'text-red-300',
                               'text-red-400', 'text-red-500', 'text-red-600', 'text-red-700', 'text-red-800',
@@ -75,9 +80,10 @@ class Tailwind:
                               'whitespace-pre-wrap'],
                'word_break': ['break-normal', 'break-words', 'break-all', 'truncate'],
                'background_attachment': ['bg-fixed', 'bg-local', 'bg-scroll'],
-               'background_color': ['bg-transparent', 'bg-black', 'bg-white', 'bg-gray-100', 'bg-gray-200',
-                                    'bg-gray-300',
-                                    'bg-gray-400', 'bg-gray-500', 'bg-gray-600', 'bg-gray-700', 'bg-gray-800',
+               'background_color': ['bg-transparent', 'bg-current', 'bg-black', 'bg-white', 'bg-gray-100',
+                                    'bg-gray-200',
+                                    'bg-gray-300', 'bg-gray-400', 'bg-gray-500', 'bg-gray-600', 'bg-gray-700',
+                                    'bg-gray-800',
                                     'bg-gray-900', 'bg-red-100', 'bg-red-200', 'bg-red-300', 'bg-red-400', 'bg-red-500',
                                     'bg-red-600', 'bg-red-700', 'bg-red-800', 'bg-red-900', 'bg-orange-100',
                                     'bg-orange-200', 'bg-orange-300', 'bg-orange-400', 'bg-orange-500', 'bg-orange-600',
@@ -99,7 +105,12 @@ class Tailwind:
                                        'bg-right-bottom', 'bg-right-top', 'bg-top'],
                'background_repeat': ['bg-repeat', 'bg-no-repeat', 'bg-repeat-x', 'bg-repeat-y', 'bg-repeat-round',
                                      'bg-repeat-space'], 'background_size': ['bg-auto', 'bg-cover', 'bg-contain'],
-               'border_color': ['border-transparent', 'border-black', 'border-white', 'border-gray-100',
+               'background_opacity': ['bg-opacity-0', 'bg-opacity-25', 'bg-opacity-50', 'bg-opacity-75', 'bg-opacity-100'],
+               'text_opacity': ['text-opacity-0', 'text-opacity-25', 'text-opacity-50', 'text-opacity-75', 'text-opacity-100'],
+               'placeholder_opacity': ['placeholder-opacity-0', 'placeholder-opacity-25', 'placeholder-opacity-50', 'placeholder-opacity-75', 'placeholder-opacity-100'],
+               'border_opacity': ['border-opacity-0', 'border-opacity-25', 'border-opacity-50', 'border-opacity-75', 'border-opacity-100'],
+               'border_color': ['border-transparent', 'border-current', 'border-black', 'border-white',
+                                'border-gray-100',
                                 'border-gray-200',
                                 'border-gray-300', 'border-gray-400', 'border-gray-500', 'border-gray-600',
                                 'border-gray-700', 'border-gray-800', 'border-gray-900', 'border-red-100',
@@ -144,51 +155,44 @@ class Tailwind:
                                     'rounded-br-full'],
                'border-radius-bl': ['rounded-bl-none', 'rounded-bl-sm', 'rounded-bl', 'rounded-bl-lg',
                                     'rounded-bl-full'],
-               'placeholder_color': ['placeholder-transparent', 'placeholder-black', 'placeholder-white',
-                                     'placeholder-gray-100', 'placeholder-gray-200',
-                                     'placeholder-gray-300', 'placeholder-gray-400', 'placeholder-gray-500',
-                                     'placeholder-gray-600', 'placeholder-gray-700',
-                                     'placeholder-gray-800', 'placeholder-gray-900', 'placeholder-red-100',
-                                     'placeholder-red-200', 'placeholder-red-300',
-                                     'placeholder-red-400', 'placeholder-red-500', 'placeholder-red-600',
-                                     'placeholder-red-700', 'placeholder-red-800',
-                                     'placeholder-red-900', 'placeholder-orange-100', 'placeholder-orange-200',
-                                     'placeholder-orange-300',
-                                     'placeholder-orange-400',
-                                     'placeholder-orange-500', 'placeholder-orange-600', 'placeholder-orange-700',
-                                     'placeholder-orange-800',
-                                     'placeholder-orange-900',
-                                     'placeholder-yellow-100', 'placeholder-yellow-200', 'placeholder-yellow-300',
-                                     'placeholder-yellow-400',
-                                     'placeholder-yellow-500',
-                                     'placeholder-yellow-600', 'placeholder-yellow-700', 'placeholder-yellow-800',
-                                     'placeholder-yellow-900',
-                                     'placeholder-green-100',
-                                     'placeholder-green-200', 'placeholder-green-300', 'placeholder-green-400',
-                                     'placeholder-green-500', 'placeholder-green-600',
-                                     'placeholder-green-700', 'placeholder-green-800', 'placeholder-green-900',
-                                     'placeholder-teal-100', 'placeholder-teal-200',
-                                     'placeholder-teal-300', 'placeholder-teal-400', 'placeholder-teal-500',
-                                     'placeholder-teal-600', 'placeholder-teal-700',
-                                     'placeholder-teal-800', 'placeholder-teal-900', 'placeholder-blue-100',
-                                     'placeholder-blue-200', 'placeholder-blue-300',
-                                     'placeholder-blue-400', 'placeholder-blue-500', 'placeholder-blue-600',
-                                     'placeholder-blue-700', 'placeholder-blue-800',
-                                     'placeholder-blue-900', 'placeholder-indigo-100', 'placeholder-indigo-200',
-                                     'placeholder-indigo-300',
-                                     'placeholder-indigo-400',
-                                     'placeholder-indigo-500', 'placeholder-indigo-600', 'placeholder-indigo-700',
-                                     'placeholder-indigo-800',
-                                     'placeholder-indigo-900',
-                                     'placeholder-purple-100', 'placeholder-purple-200', 'placeholder-purple-300',
-                                     'placeholder-purple-400',
-                                     'placeholder-purple-500',
-                                     'placeholder-purple-600', 'placeholder-purple-700', 'placeholder-purple-800',
-                                     'placeholder-purple-900',
-                                     'placeholder-pink-100',
-                                     'placeholder-pink-200', 'placeholder-pink-300', 'placeholder-pink-400',
-                                     'placeholder-pink-500', 'placeholder-pink-600',
-                                     'placeholder-pink-700', 'placeholder-pink-800', 'placeholder-pink-900'],
+               'placeholder_color': ['placeholder-transparent', 'placeholder-current', 'placeholder-black',
+                                     'placeholder-white',
+                                     'placeholder-gray-100', 'placeholder-gray-200', 'placeholder-gray-300',
+                                     'placeholder-gray-400', 'placeholder-gray-500',
+                                     'placeholder-gray-600', 'placeholder-gray-700', 'placeholder-gray-800',
+                                     'placeholder-gray-900', 'placeholder-red-100',
+                                     'placeholder-red-200', 'placeholder-red-300', 'placeholder-red-400',
+                                     'placeholder-red-500', 'placeholder-red-600',
+                                     'placeholder-red-700', 'placeholder-red-800', 'placeholder-red-900',
+                                     'placeholder-orange-100', 'placeholder-orange-200',
+                                     'placeholder-orange-300', 'placeholder-orange-400', 'placeholder-orange-500',
+                                     'placeholder-orange-600', 'placeholder-orange-700',
+                                     'placeholder-orange-800', 'placeholder-orange-900', 'placeholder-yellow-100',
+                                     'placeholder-yellow-200', 'placeholder-yellow-300',
+                                     'placeholder-yellow-400', 'placeholder-yellow-500', 'placeholder-yellow-600',
+                                     'placeholder-yellow-700', 'placeholder-yellow-800',
+                                     'placeholder-yellow-900', 'placeholder-green-100', 'placeholder-green-200',
+                                     'placeholder-green-300', 'placeholder-green-400',
+                                     'placeholder-green-500', 'placeholder-green-600', 'placeholder-green-700',
+                                     'placeholder-green-800', 'placeholder-green-900',
+                                     'placeholder-teal-100', 'placeholder-teal-200', 'placeholder-teal-300',
+                                     'placeholder-teal-400', 'placeholder-teal-500',
+                                     'placeholder-teal-600', 'placeholder-teal-700', 'placeholder-teal-800',
+                                     'placeholder-teal-900', 'placeholder-blue-100',
+                                     'placeholder-blue-200', 'placeholder-blue-300', 'placeholder-blue-400',
+                                     'placeholder-blue-500', 'placeholder-blue-600',
+                                     'placeholder-blue-700', 'placeholder-blue-800', 'placeholder-blue-900',
+                                     'placeholder-indigo-100', 'placeholder-indigo-200',
+                                     'placeholder-indigo-300', 'placeholder-indigo-400', 'placeholder-indigo-500',
+                                     'placeholder-indigo-600', 'placeholder-indigo-700',
+                                     'placeholder-indigo-800', 'placeholder-indigo-900', 'placeholder-purple-100',
+                                     'placeholder-purple-200', 'placeholder-purple-300',
+                                     'placeholder-purple-400', 'placeholder-purple-500', 'placeholder-purple-600',
+                                     'placeholder-purple-700', 'placeholder-purple-800',
+                                     'placeholder-purple-900', 'placeholder-pink-100', 'placeholder-pink-200',
+                                     'placeholder-pink-300', 'placeholder-pink-400',
+                                     'placeholder-pink-500', 'placeholder-pink-600', 'placeholder-pink-700',
+                                     'placeholder-pink-800', 'placeholder-pink-900'],
                'flex_direction': ['flex-row', 'flex-row-reverse', 'flex-col', 'flex-col-reverse'],
                'flex_wrap': ['flex-no-wrap', 'flex-wrap', 'flex-wrap-reverse'],
                'align_items': ['items-stretch', 'items-start', 'items-center', 'items-end', 'items-baseline'],
@@ -258,7 +262,8 @@ class Tailwind:
                     '-ml-40', '-ml-48', '-ml-56', '-ml-64', '-ml-px'],
                'width': ['w-0', 'w-1', 'w-2', 'w-3', 'w-4', 'w-5', 'w-6', 'w-8', 'w-10', 'w-12', 'w-16', 'w-20', 'w-24',
                          'w-32', 'w-40', 'w-48', 'w-56', 'w-64', 'w-auto', 'w-px', 'w-1/2', 'w-1/3', 'w-2/3', 'w-1/4',
-                         'w-2/4', 'w-3/4', 'w-1/5', 'w-2/5', 'w-3/5', 'w-4/5', 'w-1/6', 'w-2/6', 'w-3/6', 'w-4/6', 'w-5/6',
+                         'w-2/4', 'w-3/4', 'w-1/5', 'w-2/5', 'w-3/5', 'w-4/5', 'w-1/6', 'w-2/6', 'w-3/6', 'w-4/6',
+                         'w-5/6',
                          'w-1/12', 'w-2/12', 'w-3/12', 'w-4/12', 'w-5/12', 'w-6/12', 'w-7/12', 'w-8/12', 'w-9/12',
                          'w-10/12', 'w-11/12', 'w-full', 'w-screen'],
                'min_width': ['min-w-0', 'min-w-full'],
@@ -280,7 +285,110 @@ class Tailwind:
                'pointer_events': ['pointer-events-none', 'pointer-events-auto'],
                'resize': ['resize-none', 'resize', 'resize-y', 'resize-x'],
                'user_select': ['select-none', 'select-text', 'select-all', 'select-auto'], 'fill': ['fill-current'],
-               'stroke': ['stroke-current']}
+               'stroke': ['stroke-current'],
+               'transition': ['transition-none', 'transition-all', 'transition', 'transition-colors',
+                              'transition-opacity', 'transition-shadow', 'transition-transform'],
+               'duration': ['duration-75', 'duration-100', 'duration-150', 'duration-200', 'duration-300',
+                            'duration-500', 'duration-700', 'duration-1000'],
+               'transition_timing': ['ease-linear', 'ease-in', 'ease-out', 'ease-in-out'],
+               'transition_delay': ['delay-75', 'delay-100', 'delay-150', 'delay-200', 'delay-300', 'delay-500',
+                                    'delay-700', 'delay-1000'],
+               'scale': ['scale-0', 'scale-50', 'scale-75', 'scale-90', 'scale-95', 'scale-100', 'scale-105',
+                         'scale-110', 'scale-125', 'scale-150',
+                         'scale-y-0', 'scale-y-50', 'scale-y-75', 'scale-y-90', 'scale-y-95', 'scale-y-100',
+                         'scale-y-105', 'scale-y-110', 'scale-y-125', 'scale-y-150'],
+               'rotate': ['rotate-0', 'rotate-45', 'rotate-90', 'rotate-180', '-rotate-180', '-rotate-90',
+                          '-rotate-45'],
+               'skew': ['skew-x-0', 'skew-x-3', 'skew-x-6', 'skew-x-12', '-skew-x-12', '-skew-x-6', '-skew-x-3',
+                        'skew-y-0', 'skew-y-3', 'skew-y-6', 'skew-y-12', '-skew-y-12', '-skew-y-6', '-skew-y-3'],
+               'transform_origin': ['origin-center', 'origin-top', 'origin-top-right', 'origin-right',
+                                    'origin-bottom-right', 'origin-bottom', 'origin-bottom-left', 'origin-left',
+                                    'origin-top-left'],
+               'translate': ['translate-x-0', 'translate-x-1', 'translate-x-2', 'translate-x-3', 'translate-x-4',
+                             'translate-x-5', 'translate-x-6', 'translate-x-8', 'translate-x-10', 'translate-x-12',
+                             'translate-x-16', 'translate-x-20', 'translate-x-24', 'translate-x-32', 'translate-x-40',
+                             'translate-x-48', 'translate-x-56', 'translate-x-64', 'translate-x-px', '-translate-x-1',
+                             '-translate-x-2', '-translate-x-3', '-translate-x-4', '-translate-x-5', '-translate-x-6',
+                             '-translate-x-8', '-translate-x-10', '-translate-x-12', '-translate-x-16',
+                             '-translate-x-20', '-translate-x-24', '-translate-x-32', '-translate-x-40',
+                             '-translate-x-48', '-translate-x-56', '-translate-x-64', '-translate-x-px',
+                             '-translate-x-full', '-translate-x-1/2', 'translate-x-1/2', 'translate-x-full',
+                             'translate-y-0', 'translate-y-1', 'translate-y-2', 'translate-y-3', 'translate-y-4',
+                             'translate-y-5', 'translate-y-6', 'translate-y-8', 'translate-y-10', 'translate-y-12',
+                             'translate-y-16', 'translate-y-20', 'translate-y-24', 'translate-y-32', 'translate-y-40',
+                             'translate-y-48', 'translate-y-56', 'translate-y-64', 'translate-y-px', '-translate-y-1',
+                             '-translate-y-2', '-translate-y-3', '-translate-y-4', '-translate-y-5', '-translate-y-6',
+                             '-translate-y-8', '-translate-y-10', '-translate-y-12', '-translate-y-16',
+                             '-translate-y-20', '-translate-y-24', '-translate-y-32', '-translate-y-40',
+                             '-translate-y-48', '-translate-y-56', '-translate-y-64', '-translate-y-px',
+                             '-translate-y-full', '-translate-y-1/2', 'translate-y-1/2', 'translate-y-full'],
+               'divide_width': ['divide-x-0', 'divide-x-2', 'divide-x-4', 'divide-x-8', 'divide-x', 'divide-y-0',
+                                'divide-y-2', 'divide-y-4', 'divide-y-8', 'divide-y', 'divide-x-reverse',
+                                'divide-y-reverse'],
+               'divide_color': ['divide-transparent', 'divide-current', 'divide-black', 'divide-white',
+                                'divide-gray-100', 'divide-gray-200', 'divide-gray-300', 'divide-gray-400',
+                                'divide-gray-500', 'divide-gray-600', 'divide-gray-700', 'divide-gray-800',
+                                'divide-gray-900', 'divide-red-100', 'divide-red-200', 'divide-red-300',
+                                'divide-red-400', 'divide-red-500', 'divide-red-600', 'divide-red-700',
+                                'divide-red-800', 'divide-red-900', 'divide-orange-100', 'divide-orange-200',
+                                'divide-orange-300', 'divide-orange-400', 'divide-orange-500', 'divide-orange-600',
+                                'divide-orange-700', 'divide-orange-800', 'divide-orange-900', 'divide-yellow-100',
+                                'divide-yellow-200', 'divide-yellow-300', 'divide-yellow-400', 'divide-yellow-500',
+                                'divide-yellow-600', 'divide-yellow-700', 'divide-yellow-800', 'divide-yellow-900',
+                                'divide-green-100', 'divide-green-200', 'divide-green-300', 'divide-green-400',
+                                'divide-green-500', 'divide-green-600', 'divide-green-700', 'divide-green-800',
+                                'divide-green-900', 'divide-teal-100', 'divide-teal-200', 'divide-teal-300',
+                                'divide-teal-400', 'divide-teal-500', 'divide-teal-600', 'divide-teal-700',
+                                'divide-teal-800', 'divide-teal-900', 'divide-blue-100', 'divide-blue-200',
+                                'divide-blue-300', 'divide-blue-400', 'divide-blue-500', 'divide-blue-600',
+                                'divide-blue-700', 'divide-blue-800', 'divide-blue-900', 'divide-indigo-100',
+                                'divide-indigo-200', 'divide-indigo-300', 'divide-indigo-400', 'divide-indigo-500',
+                                'divide-indigo-600', 'divide-indigo-700', 'divide-indigo-800', 'divide-indigo-900',
+                                'divide-purple-100', 'divide-purple-200', 'divide-purple-300', 'divide-purple-400',
+                                'divide-purple-500', 'divide-purple-600', 'divide-purple-700', 'divide-purple-800',
+                                'divide-purple-900', 'divide-pink-100', 'divide-pink-200', 'divide-pink-300',
+                                'divide-pink-400', 'divide-pink-500', 'divide-pink-600', 'divide-pink-700',
+                                'divide-pink-800', 'divide-pink-900'],
+               'divide_opacity': ['divide-opacity-0', 'divide-opacity-25', 'divide-opacity-50', 'divide-opacity-75',
+                                  'divide-opacity-100'],
+               'grid_template_cols': ['grid-cols-1', 'grid-cols-2', 'grid-cols-3', 'grid-cols-4', 'grid-cols-5',
+                                      'grid-cols-6', 'grid-cols-7', 'grid-cols-8', 'grid-cols-9', 'grid-cols-10',
+                                      'grid-cols-11', 'grid-cols-12'],
+               'grid_col_start_end': ['col-auto', 'col-span-1', 'col-span-2', 'col-span-3', 'col-span-4', 'col-span-5',
+                                      'col-span-6', 'col-span-7', 'col-span-8', 'col-span-9', 'col-span-10',
+                                      'col-span-11'],
+               'grid_template_rows': ['grid-rows-1', 'grid-rows-2', 'grid-rows-3', 'grid-rows-4', 'grid-rows-5',
+                                      'grid-rows-6', 'grid-rows-none'],
+               'grid_row_start_end': ['row-auto', 'row-span-1', 'row-span-2', 'row-span-3', 'row-span-4', 'row-span-5',
+                                      'row-span-6', 'row-start-1', 'row-start-2', 'row-start-3', 'row-start-4',
+                                      'row-start-5', 'row-start-6', 'row-start-7', 'row-start-auto', 'row-end-1',
+                                      'row-end-2', 'row-end-3', 'row-end-4', 'row-end-5', 'row-end-6', 'row-end-7',
+                                      'row-end-auto'],
+               'grid_gap': ['gap-0', 'gap-1', 'gap-2', 'gap-3', 'gap-4', 'gap-5', 'gap-6', 'gap-8', 'gap-10', 'gap-12',
+                            'gap-16', 'gap-20', 'gap-24', 'gap-32', 'gap-40', 'gap-48', 'gap-56', 'gap-64', 'gap-px',
+                            'row-gap-0', 'row-gap-1', 'row-gap-2', 'row-gap-3', 'row-gap-4', 'row-gap-5', 'row-gap-6',
+                            'row-gap-8', 'row-gap-10', 'row-gap-12', 'row-gap-16', 'row-gap-20', 'row-gap-24',
+                            'row-gap-32', 'row-gap-40', 'row-gap-48', 'row-gap-56', 'row-gap-64', 'row-gap-px',
+                            'col-gap-0', 'col-gap-1', 'col-gap-2', 'col-gap-3', 'col-gap-4', 'col-gap-5', 'col-gap-6',
+                            'col-gap-8', 'col-gap-10', 'col-gap-12', 'col-gap-16', 'col-gap-20', 'col-gap-24',
+                            'col-gap-32', 'col-gap-40', 'col-gap-48', 'col-gap-56', 'col-gap-64', 'col-gap-px'],
+               'grid_auto_flow': ['grid-flow-row', 'grid-flow-col', 'grid-flow-row-dense', 'grid-flow-col-dense'],
+               'space_between': ['space-x-0', 'space-x-1', 'space-x-2', 'space-x-3', 'space-x-4', 'space-x-5',
+                                 'space-x-6', 'space-x-8', 'space-x-10', 'space-x-12', 'space-x-16', 'space-x-20',
+                                 'space-x-24', 'space-x-32', 'space-x-40', 'space-x-48', 'space-x-56', 'space-x-64',
+                                 'space-x-px', '-space-x-1', '-space-x-2', '-space-x-3', '-space-x-4', '-space-x-5',
+                                 '-space-x-6', '-space-x-8', '-space-x-10', '-space-x-12', '-space-x-16', '-space-x-20',
+                                 '-space-x-24', '-space-x-32', '-space-x-40', '-space-x-48', '-space-x-56',
+                                 '-space-x-64', '-space-x-px', 'space-y-0', 'space-y-1', 'space-y-2', 'space-y-3',
+                                 'space-y-4', 'space-y-5', 'space-y-6', 'space-y-8', 'space-y-10', 'space-y-12',
+                                 'space-y-16', 'space-y-20', 'space-y-24', 'space-y-32', 'space-y-40', 'space-y-48',
+                                 'space-y-56', 'space-y-64', 'space-y-px', '-space-y-1', '-space-y-2', '-space-y-3',
+                                 '-space-y-4', '-space-y-5', '-space-y-6', '-space-y-8', '-space-y-10', '-space-y-12',
+                                 '-space-y-16', '-space-y-20', '-space-y-24', '-space-y-32', '-space-y-40',
+                                 '-space-y-48', '-space-y-56', '-space-y-64', '-space-y-px', 'space-x-reverse',
+                                 'space-y-reverse'],
+               'animation': ['animate-none', 'animate-spin', 'animate-ping', 'animate-pulse', 'animate-bounce']
+               }
 
     @staticmethod
     def create_reverse_dict(tw):
@@ -293,8 +401,6 @@ class Tailwind:
     tw_reverse_dict = create_reverse_dict.__func__(tw_dict)
 
     def set_class(self, tw_class, modifier=''):
-        # Set Tailwind class. Does not yet support all version 1.2 classes
-        # Set those directly
         if modifier and modifier not in Tailwind.pseudo_classes:
             raise Exception(f'No Tailwind pseudo-class (modifier) named {modifier}')
         if tw_class not in Tailwind.tw_reverse_dict:
@@ -324,5 +430,4 @@ class Tailwind:
             else:
                 self.set_class(c[0])
 
-    def has_class(self, class_name):
-        return class_name in self.classes.split()
+
